Index: trunk/MagicSoft/Mars/Makefile
===================================================================
--- trunk/MagicSoft/Mars/Makefile	(revision 711)
+++ trunk/MagicSoft/Mars/Makefile	(revision 712)
@@ -62,7 +62,7 @@
 
 # Use $(CXX) -v ... for a more verbose output
-$(PROGRAMS): $(LIBRARIES) $(OBJS) $(HEADERS) MCint.o $(PROGRAMS:=.o) 
+$(PROGRAMS): $(LIBRARIES) mars.so $(HEADERS) MCint.o $(PROGRAMS:=.o) 
 	@echo " Linking $@ ..." 
-	$(CXX) $(CXXFLAGS) $@.o $(OBJS) $(MARS_LIB) MCint.o $(ROOTGLIBS) -o $@
+	$(CXX) $(CXXFLAGS) $@.o lib/mars.so $(MARS_LIB) MCint.o $(ROOTGLIBS) -o $@
 
 $(SOLIB): $(LIBRARIES) $(OBJS) $(HEADERS) MCint.o
Index: trunk/MagicSoft/Mars/mhist/MFillHFadc.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MFillHFadc.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MFillHFadc.h	(revision 712)
@@ -25,5 +25,5 @@
   Bool_t Process() ;
   
-  ClassDef(MFillHFadc, 0)	// Task to fill a MHistosAdc Container with data
+  ClassDef(MFillHFadc, 0)  // Task to fill the fadc data into histograms
 
 };
Index: trunk/MagicSoft/Mars/mhist/MFillHHillas.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MFillHHillas.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MFillHHillas.h	(revision 712)
@@ -25,6 +25,5 @@
   Bool_t Process() ;
   
-  ClassDef(MFillHHillas, 0)	// Task to fill the Hillas histograms
-
+  ClassDef(MFillHHillas, 0) // Task to fill the Hillas parameters into histograms
 };
     
Index: trunk/MagicSoft/Mars/mhist/MFillHStarMap.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MFillHStarMap.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MFillHStarMap.h	(revision 712)
@@ -25,5 +25,5 @@
   Bool_t Process() ;
   
-  ClassDef(MFillHStarMap, 0)	// Task to fill the Hillas histograms
+  ClassDef(MFillHStarMap, 0) // Task to fill a 2-dim histogram by the Hillas parameters
 
 };
Index: trunk/MagicSoft/Mars/mhist/MHFadcCam.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHFadcCam.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MHFadcCam.h	(revision 712)
@@ -48,5 +48,5 @@
     }
 
-    ClassDef(MHFadcCam, 1)	// list of Histograms with ADC spectra
+    ClassDef(MHFadcCam, 1) // A list of histograms storing the Fadc spektrum of one pixel
 };
 
Index: trunk/MagicSoft/Mars/mhist/MHFadcPix.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHFadcPix.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MHFadcPix.h	(revision 712)
@@ -31,5 +31,5 @@
     void Draw(Option_t *opt=NULL);
 
-    ClassDef(MHFadcPix, 1)
+    ClassDef(MHFadcPix, 1) // Conatiner to hold two histograms container spektrums for the lo-/hi gain of one pixel
 };
 
Index: trunk/MagicSoft/Mars/mhist/MHHillas.cc
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHHillas.cc	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MHHillas.cc	(revision 712)
@@ -32,7 +32,10 @@
 
     //
-    //   loop over all Pixels and create two histograms
-    //   one for the Low and one for the High gain
-    //   connect all the histogram with the container fHist
+    // loop over all Pixels and create two histograms
+    // one for the Low and one for the High gain
+    // connect all the histogram with the container fHist
+    //
+    // FIXME! Make the histograms looking that they can be used for
+    //        presentations (axis title, ...)
     //
     fAlpha  = new TH1F("Alpha [deg]", "Alpha of Hillas",   90, 0,  90);
Index: trunk/MagicSoft/Mars/mhist/MHHillas.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHHillas.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MHHillas.h	(revision 712)
@@ -34,5 +34,5 @@
     void Draw(Option_t *opt=NULL);
 
-    ClassDef(MHHillas, 1)	// list of Histograms with ADC spectra
+    ClassDef(MHHillas, 1) // Container which holds hostograms for the Hillas parameters
 };
 
Index: trunk/MagicSoft/Mars/mhist/MHStarMap.cc
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHStarMap.cc	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MHStarMap.cc	(revision 712)
@@ -2,4 +2,8 @@
 //
 // MHStarMap
+//
+// This class contains a 2-dimensional histogram. It should show some
+// kind of star map. The algorith which calculates the star map
+// from the Hillas parameters (Fill) can be enhanced.
 //
 ///////////////////////////////////////////////////////////////////////
Index: trunk/MagicSoft/Mars/mhist/MHStarMap.h
===================================================================
--- trunk/MagicSoft/Mars/mhist/MHStarMap.h	(revision 711)
+++ trunk/MagicSoft/Mars/mhist/MHStarMap.h	(revision 712)
@@ -32,5 +32,5 @@
     void Draw(Option_t *opt=NULL);
 
-    ClassDef(MHStarMap, 1)	// list of Histograms with ADC spectra
+    ClassDef(MHStarMap, 1) // Container to hold 2-dim histogram (starmap)
 };
 
Index: trunk/MagicSoft/Mars/mmontecarlo/MCollArea.h
===================================================================
--- trunk/MagicSoft/Mars/mmontecarlo/MCollArea.h	(revision 711)
+++ trunk/MagicSoft/Mars/mmontecarlo/MCollArea.h	(revision 712)
@@ -1,8 +1,20 @@
-#ifndef __MCollArea__
-#define __MCollArea__
+#ifndef MCOLLAREA_H
+#define MCOLLAREA_H
 
+#ifndef MAGIC_H
+#include "MAGIC.h"
+#endif
+#ifndef MPARCONTAINER_H
 #include "MParContainer.h"
+#endif
 
-#include <TH2.h>
+//
+// because of some strange reason this cannot be put into MonteCarloIncl
+//
+#ifndef TH1_H
+#include <TH1.h>
+#endif
+
+class TH2D;
 
 class MCollArea : public MParContainer { 
Index: trunk/MagicSoft/Mars/mmontecarlo/MCollAreaTrigger.cc
===================================================================
--- trunk/MagicSoft/Mars/mmontecarlo/MCollAreaTrigger.cc	(revision 711)
+++ trunk/MagicSoft/Mars/mmontecarlo/MCollAreaTrigger.cc	(revision 712)
@@ -65,5 +65,5 @@
   //
 
-  fCollArea->CalculateEffi() ; 
+  fCollArea->CalcEfficiency() ;
 
   return kTRUE ; 
Index: trunk/MagicSoft/Mars/mmontecarlo/MonteCarloIncl.h
===================================================================
--- trunk/MagicSoft/Mars/mmontecarlo/MonteCarloIncl.h	(revision 711)
+++ trunk/MagicSoft/Mars/mmontecarlo/MonteCarloIncl.h	(revision 712)
@@ -1,5 +1,3 @@
 #ifndef __CINT__
 
-#include "MParContainer.h"
-
 #endif // __CINT__
Index: trunk/MagicSoft/Mars/mraw/MRawEvtPixelIter.h
===================================================================
--- trunk/MagicSoft/Mars/mraw/MRawEvtPixelIter.h	(revision 711)
+++ trunk/MagicSoft/Mars/mraw/MRawEvtPixelIter.h	(revision 712)
@@ -66,5 +66,5 @@
     ULong_t GetSumHiGainFadcSamples() const;
 
-    Bool_t IsLoGain() const
+    Bool_t HasLoGain() const
     {
         //
@@ -80,5 +80,5 @@
         // for the actual pixel, else return zero
         //
-        return IsLoGain() ? fLoGainPos : NULL;
+        return HasLoGain() ? fLoGainPos : NULL;
     }
 

Index: trunk/MagicSoft/Mars/mraw/MRawEvtPixelIter.cc
===================================================================
--- trunk/MagicSoft/Mars/mraw/MRawEvtPixelIter.cc	(revision 711)
+++ trunk/MagicSoft/Mars/mraw/MRawEvtPixelIter.cc	(revision 712)
@@ -14,5 +14,5 @@
 //     //   pixel.GetPixelId();
 //     //   pixel.GetHiGainFadcSamples()[i]; // i is the number of the slice
 //     //   pixel.IsLoGain();                // check if pixel has
 //     //   pixel.GetLoGainFadcSamples()[i]; // i is the number of the slice
 //
@@ -123,5 +123,5 @@
     // return the sum of the lo gain samples of the present pixel
     //
-    if (!IsLoGain())
+    if (!HasLoGain())
         return 0;
 
@@ -14,5 +14,5 @@
 //     //   pixel.GetPixelId();
 //     //   pixel.GetHiGainFadcSamples()[i]; // i is the number of the slice
-//     //   pixel.IsLoGain();                // check if pixel has
+//     //   pixel.HasLoGain();               // check if pixel has
 //     //   pixel.GetLoGainFadcSamples()[i]; // i is the number of the slice
 //